pub(crate) struct RepeatByte {
pub(crate) byte: u8,
pub(crate) count: u8,
}Expand description
A helper for repeating a single byte utilizing Byte.
This is limited to repeating a byte up to u8::MAX times in order
to reduce its size overhead. And in practice, Jiff just doesn’t
need more than this (at time of writing, 2025-11-29).
Fields
byte: u8count: u8Trait Implementations
Sourceimpl Debug for RepeatByte
impl Debug for RepeatByte